@@ -263,12 +263,13 @@ extern "C" {
 
     pub fn ditto_collection(ditto: &'_ Ditto, name: char_p::Ref<'_>) -> c_int;
 
-    pub fn ditto_collection_insert(
+    pub fn ditto_collection_insert_value(
         ditto: &'_ Ditto,
         coll_name: char_p::Ref<'_>,
-        transaction: &'_ mut CWriteTransaction,
-        document: c::Box<Document>,
+        doc_cbor: c_slice::Ref<'_, u8>,
+        doc_id: Option<c_slice::Ref<'_, u8>>,
         write_strategy: WriteStrategyRs,
+        txn: Option<&'_ mut CWriteTransaction>,
     ) -> c::Result_BoxedSlice<u8>;
 
     pub fn ditto_collection_update(
@@ -636,6 +637,8 @@ extern "C" {
         provider: char_p::Ref<'_>,
     ) -> c_int;
 
+    pub fn ditto_auth_client_logout(auth_client: &'_ AuthClient) -> c_int;
+
     pub type LoginProvider: Send + Sync;
 
     #[drop]
